/*
 * Copyright 2015 Djembe.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package md.djembe.beans;

import java.util.Date;
import java.util.Map;

import javax.faces.application.FacesMessage;
import javax.faces.application.ViewHandler;
import javax.faces.component.UIViewRoot;
import javax.faces.context.ExternalContext;
import javax.faces.context.FacesContext;
import javax.faces.context.Flash;
import javax.servlet.http.HttpServletRequest;

import md.djembe.entities.UserEntity;

import org.apache.log4j.Logger;


/**
 * Utility classes for the JSF Managed Beans
 * 
 * @author M. Diallo
 *
 */
public abstract class AbstractBean {
    
    /** Logger used by all the managed beans  */
    private final Logger LOGGER = Logger.getLogger( getClass( ) );
    
    private FacesContext facesContext;
    
    protected UserEntity getCurrentUser() {
        return (UserEntity) getSessionMap( ).get( "currentUser" );
    }

    protected void setCurrentUser(UserEntity currentUser) {
        getSessionMap( ).remove( "currentUser" );
        if( null != currentUser ) {
            getSessionMap( ).put( "currentUser" , currentUser );
        }
    }

    protected boolean isUserLoggedIn( ) {
        return getSessionMap( ).containsKey( "currentUser" );
    }

    protected FacesContext getFacesContext( ) {
        return FacesContext.getCurrentInstance( );
    }

    protected void setFacesContext( FacesContext facesContext ) {
        this.facesContext = facesContext;
    }

    protected ExternalContext getExternalContext( ) {
        return getFacesContext( ).getExternalContext( );
    }

    protected Map<String , Object> getRequestMap( ) {
        return getExternalContext( ).getRequestMap( );
    }

    protected HttpServletRequest getHttpRequest( ) {
        return (HttpServletRequest) getExternalContext( ).getRequest( );
    }

    protected Map<String , Object> getSessionMap( ) {
        return getExternalContext( ).getSessionMap( );
    }

    protected Flash getFlash( ) {
        return getExternalContext( ).getFlash( );
    }

    protected void addErrorMessage( final String clientId, final String message ) {
        FacesMessage facesMessage = new FacesMessage( FacesMessage.SEVERITY_ERROR , message , message );
        getFacesContext( ).addMessage( clientId , facesMessage );
        getFlash( ).setKeepMessages( true );
    }

    protected void addSuccessMessage( final String clientId, final String message ) {
        FacesMessage facesMessage = new FacesMessage( FacesMessage.SEVERITY_INFO , message , message );
        getFacesContext( ).addMessage( clientId , facesMessage );
        getFlash( ).setKeepMessages( true );
    }

    protected Date getCurrentDate() {
        return new Date( System.currentTimeMillis( ) );
    }

    protected void refreshPage( ) {
        facesContext = getFacesContext( );
        String viewId = facesContext.getViewRoot( ).getViewId( );
        ViewHandler handler = facesContext.getApplication( ).getViewHandler( );
        UIViewRoot root = handler.createView( facesContext , viewId );
        root.setViewId( viewId );
        facesContext.setViewRoot( root );
    }
    
    protected Logger getLogger( ) {
        return LOGGER;
    }    
    
    protected void logDebug( final String... messages ) {
        LOGGER.debug( messages );
    }
    
    protected void logInfo( final String message) {
        LOGGER.info( message );
    }
    
    protected void logWarn( final String message) {
        LOGGER.warn( message );
    }
    
    protected void logError( final String message) {
        logError( message, null );
    }
    
    protected void logError( final String message, Throwable t) {
        if( t != null ) {
            LOGGER.error( message , t );
           // addToAlertEmail( t );
        }else {
            LOGGER.error( message );
        }
        
    }
    
    /**
     * Add the exception that occurred to the periodic alert email
     * @param throwable the exception to record
     */
//    protected void addToAlertEmail( final Throwable throwable  ) {
//        EmailContent emailContent = new EmailContent( );
//        emailContent.setSubject( throwable.getMessage( ) );
//        emailContent.setBody( ExceptionUtil.toString( throwable ) );
//        BackgroundTask emailTask = new MailBackgroundTask( emailContent ) ;
//        BackgroundTaskHolder.addTask( emailTask ) ;
//    }
    
   
}