/*
 * Copyright 2015 Djembe.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package md.djembe.beans;

import java.io.Serializable;
import java.util.List;

import javax.annotation.PostConstruct;
import javax.faces.bean.ManagedBean;
import javax.faces.bean.SessionScoped;
import javax.validation.constraints.NotNull;

import md.djembe.entities.ArticleEntity;
import md.djembe.entities.UserEntity;
import md.djembe.exceptions.PersistEntityException;
import md.djembe.facades.ArticleFacade;
import md.djembe.facades.UserFacade;


@ManagedBean(name = "blogBean")
@SessionScoped
public class BlogBean extends AbstractBean implements Serializable {
    
    private static final long serialVersionUID = 11545458946454649L;
    
    private String blogBody;
    
    @NotNull
    private String blogTitle;
    
    @NotNull
    private String language;
    
    @NotNull
    private String blogType;
    
    private List<ArticleEntity> allBlogArticles;
    
    private List<ArticleEntity> allArticles;
    
    private ArticleEntity blogEntity;

        
    @PostConstruct
    public void init(){
    	allBlogArticles = new ArticleFacade( ).getAllBlogArticle( );
    	
    }
    //############################################
    // CRUD
    //############################################
    
    
    
    /**
     * Create a new article.
     */
    public String createNewBlog( ) {
    	System.out.println("Creating new blog... ");
    	UserEntity currentUser = getCurrentUser();
    	if( currentUser == null){
    		currentUser = new UserFacade().find( new Long(1)) ;
    	}
        logInfo( String.format( "Saving a new article to the database, for user %s.", currentUser ) );
        try {
            blogBody = blogBody.replaceAll( "&lt;" , "&amp;lt;" )
                               .replaceAll( "&gt;" , "&amp;gt;" );
            
            
            
            // FIXME : fix language
            new ArticleFacade( ).createNewArticle( blogBody , 
                                                   blogTitle , 
                                                   blogType ,
                                                   "en" , 
                                                   currentUser );
            
            refreshAllBlogArticles( );
            
            resetFields( );
        }catch( PersistEntityException pee ) {
        	pee.printStackTrace();
            logError( String.format( "Error saving a new article for user %s " ,
                                getCurrentUser( ) ) , pee );
        }
        return "pretty:listBlog";
    }
    
    
    /**
     * Displays the selected article  
     * @param article
     * @return
     */
    public String displayBlog( ArticleEntity article ){
        this.blogEntity = article ;
        return "pretty:blogArticles";
    }
     
    
    /**
     * Display the articles in a text box for edit
     */
    public String editBlog( ArticleEntity article ) {
        setBlogEntity( article );
        return "pretty:editBlog";
    }
    
    /**
     * Save the edited article to database
     */
    public String updateBlog( ArticleEntity article ){
        logInfo( String.format( "Updating article for user %s.", getCurrentUser( ) ) );
        article.setArticleBody( article.getArticleBody( )
                                       .replaceAll( "&lt;" , "&amp;lt;" )
                                       .replaceAll( "&gt;" , "&amp;gt;" ) );

        new ArticleFacade( ).edit( article );
        refreshAllBlogArticles( );
        return "pretty:listBlog";
    }
    
    /**
     * Mark the article as deleted but does not remove from the database
     */
    public void deleteBlog( ArticleEntity article ){
        article.setDeleted( true );
        new ArticleFacade( ).edit( article );
        refreshAllBlogArticles( );
    }
    
    
    /**
     * Navigate to the new blog page
     * @return
     */
    public String newBlog( ){
        resetFields( );
        return "pretty:newBlog";
    }
   
    /**
     * Navigate to the preview blog page
     * @param blog
     * @return
     */
    public String previewBlog( ArticleEntity blog ){
        setBlogEntity( blog );
        return "pretty:viewBlog";
    }
   
    /**
     * Change the visibility of the blog to public or hidden
     * @param blog
     */
    public void toggleBlogVisibilty( ArticleEntity blog ) {
        blog.setIsPublic( ! blog.isIsPublic( ) );
        new ArticleFacade( ).edit( blog );
        refreshAllBlogArticles( );
    }
    
    
    /**
     * Reset the data in the blog page
     */
    private void resetFields( ) {
        blogBody = null;
        blogTitle = null;
        language = null;
    }
    
    
    /**
     * Refresh all the blog articles
     */
    private void refreshAllBlogArticles( ) {
        allBlogArticles = new ArticleFacade( ).getAllBlogArticle( );
    }
   
   
    // ###############################################################
    // GETTER AND SETTERS
    // ###############################################################
    
    /**
     * Retrieve all the articles
     */
    public List<ArticleEntity> getAllArticles() {
        return allArticles;
    }
    
    /**
     * Retrieve all the  blogs article and display on the page
     */
    public List<ArticleEntity> getAllBlogArticles( ) {
        return allBlogArticles;
    }
 
    public String getBlogBody( ) {
        return blogBody;
    }

    public void setBlogBody( String blogBody ) {
        this.blogBody = blogBody;
    }

    public String getBlogTitle( ) {
        return blogTitle;
    }

    public void setBlogTitle( String blogTitle ) {
        this.blogTitle = blogTitle;
    }

    public String getLanguage( ) {
        return language;
    }

    public void setLanguage( String language ) {
        this.language = language;
    }

    public ArticleEntity getBlogEntity( ) {
        return blogEntity;
    }

    public void setBlogEntity( ArticleEntity blogEntity ) {
        this.blogEntity = blogEntity;
    }

    public String getBlogType( ) {
        return blogType;
    }

    public void setBlogType( String blogType ) {
        this.blogType = blogType;
    }
    
    
    
}
