/*
 * Copyright 2015 Djembe.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package md.djembe.beans;

import java.util.ArrayList;
import java.util.List;

import javax.annotation.PostConstruct;
import javax.faces.bean.ManagedBean;
import javax.faces.bean.RequestScoped;
import javax.validation.constraints.NotNull;

import md.djembe.exceptions.MessagingException;
import md.djembe.facades.MessageFacade;

@ManagedBean
@RequestScoped
public class ContactBean extends AbstractBean {
    
    private String name;
    
    @NotNull
    private String email;
    
    private String subject;
    
    @NotNull
    private String message;
    
    private List<String> subjectValues;
    
    @PostConstruct
    public void init( ){
    	System.out.println("Runnning post constructor...");
    	subjectValues = new ArrayList<String>( );
    	subjectValues.add("Choose One:") ;
    	subjectValues.add("General Customer Service") ;
    	subjectValues.add("Suggestions");
    	subjectValues.add("Product Support");
    }
    
    
    //############################################
    // CRUD
    //############################################
    
    
    /**
     * Calls the JPA facade to store the message in the DB
     * @return
     */
    public String sendMessage( ) {
        
        logInfo( "New message received." );
        try {
            new MessageFacade( ).createNewMessage( name , email , subject , message );
        }
        catch( MessagingException me ) {
            logError(
                    String.format(
                            "Error adding the new message to the system from user : %s , email : %s, message : %s" ,
                            name , email ) , me );
        }
        return "pretty:home";
    }
    
    
    
    
    
    // ###############################################################
    // GETTER AND SETTERS
    // ###############################################################
    
    public List<String> getSubjectValues( ) {
		return subjectValues;
	}
    
    public String getName( ) {
        return name;
    }
    
    public void setName( String name ) {
        this.name = name;
    }
    
    public String getEmail( ) {
        return email;
    }
    
    public void setEmail( String email ) {
        this.email = email;
    }
    
    public String getSubject( ) {
        return subject;
    }
    
    public void setSubject( String subject ) {
        this.subject = subject;
    }
    
    public String getMessage( ) {
        return message;
    }
    
    public void setMessage( String message ) {
        this.message = message;
    }
    

}
