/*
 * Copyright 2015 Djembe.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package md.djembe.beans;

import java.io.Serializable;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.PostConstruct;
import javax.faces.bean.ManagedBean;
import javax.faces.bean.SessionScoped;
import javax.faces.event.AjaxBehaviorEvent;
import javax.persistence.NoResultException;

import md.djembe.entities.SettingEntity;
import md.djembe.facades.SettingFacade;

@ManagedBean(name = "settingBean")
@SessionScoped
public class SettingBean extends AbstractBean implements Serializable {

	private Map<String, String> settingOptions = new HashMap<>();

	private static final long serialVersionUID = 1L;

	@PostConstruct
	public void init() {
		System.out.println("initialising the options...");
		List<SettingEntity> options = new SettingFacade().findAll();
		for (SettingEntity option : options) {
			settingOptions.put(option.getSettingName(), option.getSettingValue());
		}
	}

	public void valueChanged( AjaxBehaviorEvent event){
		
		System.out.println( "The new value is : " + settingOptions.get("imagesPath") );
		SettingFacade settingFacade = new SettingFacade();
		for (String settingName : settingOptions.keySet()) {
			try{
			SettingEntity optionEntity = settingFacade.findByName(settingName);
			optionEntity.setSettingValue( settingOptions.get(settingName));
			settingFacade.edit(optionEntity);
			}catch(NoResultException nre){
				SettingEntity settingEntity = new SettingEntity();
				settingEntity.setSettingName( settingName);
				settingEntity.setSettingValue(settingOptions.get(settingName));
				settingFacade.create(settingEntity);
			}
		}
		
	}

	public Map<String, String> getSettingOptions() {
		return settingOptions;
	}

	public void setSettingOptions(Map<String, String> settingOptions) {
		this.settingOptions = settingOptions;
	}

}
