/*
 * Copyright 2015 Djembe.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package md.djembe.beans;

import java.io.Serializable;
import java.util.List;

import javax.faces.bean.ManagedBean;
import javax.faces.bean.SessionScoped;

import md.djembe.entities.TemplateEntity;
import md.djembe.facades.TemplateFacade;

@ManagedBean(name = "templateBean")
@SessionScoped
public class TemplateBean extends AbstractBean implements Serializable {

	private static final long serialVersionUID = 1L;
	private String templateName;
	private String headTagContent;
	private String headerContent;
	private String footerContent;
	private String scriptContent;
	private TemplateEntity templateEntity;

	public String createNewTemplate( ) {
		System.out.println("Saving new template : ");
		new TemplateFacade().createNewTemplate(templateName, headTagContent,
				headerContent, footerContent, scriptContent);
		
		return "pretty:listTemplates";
	}
	
	public String previewTemplate( TemplateEntity templateEntity ){
		this.templateEntity = templateEntity;
		return "pretty:viewTemplates";
	}
	
	
	public String editTemplate( TemplateEntity templateEntity ){
		this.templateEntity = templateEntity;
		return "pretty:editTemplates";
	} 
	
	public String updateTemplate( TemplateEntity templateEntity){
		new TemplateFacade().edit(templateEntity);
		return "pretty:listTemplates";
	}
	
	public String deleteTemplate( TemplateEntity templateEntity ){
		new TemplateFacade().remove(templateEntity);
		return "pretty:listTemplates";
	}
	
	public String setActive( TemplateEntity templateEntity ){
		TemplateFacade templateFacade = new TemplateFacade();
		List<TemplateEntity> templateEntities = templateFacade.findAll();
		for(TemplateEntity template: templateEntities){
			template.setActive(false);
			templateFacade.edit(template);
		}
		templateEntity.setActive(true);
		templateFacade.edit(templateEntity);
		return "pretty:listTemplates";
	}
	

	public String getTemplateName() {
		return templateName;
	}

	public void setTemplateName(String templateName) {
		this.templateName = templateName;
	}

	public String getHeadTagContent() {
		return headTagContent;
	}

	public void setHeadTagContent(String headTagContent) {
		this.headTagContent = headTagContent;
	}
	
	
	public String getHeaderContent() {
		return headerContent;
	}

	public void setHeaderContent(String headerContent) {
		this.headerContent = headerContent;
	}

	public String getFooterContent() {
		return footerContent;
	}

	public void setFooterContent(String footerContent) {
		this.footerContent = footerContent;
	}

	public String getScriptContent() {
		return scriptContent;
	}

	public void setScriptContent(String scriptContent) {
		this.scriptContent = scriptContent;
	}
	
	public TemplateEntity getTemplateEntity() {
		return templateEntity;
	}

	public void setTemplateEntity(TemplateEntity templateEntity) {
		this.templateEntity = templateEntity;
	}

	public List<TemplateEntity> getTemplateList() {
		return new TemplateFacade().findAll();
	}

}
