/*
 * Copyright 2015 Djembe.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package md.djembe.beans;

import java.io.Serializable;

import javax.faces.bean.ManagedBean;
import javax.faces.bean.RequestScoped;
import javax.servlet.ServletException;
import javax.validation.constraints.NotNull;

import md.djembe.entities.UserEntity;
import md.djembe.facades.UserFacade;


@ManagedBean(name = "userLoginBean")
@RequestScoped
public class UserLoginBean extends AbstractBean implements Serializable {

   
    private static final long serialVersionUID = -179874654984657787L;
    
    @NotNull
    private String username;
    
    @NotNull
    private String password;
    
    
    //############################################
    // CRUD
    //############################################

    /**
     * Return true if user exist and successfully logged in otherwise false
     * @param userType
     * @return the outcome
     */
    public String login( String userType ) {
        String outcome = "";
        try {
        	
            // logout the user in case already logged in
            getHttpRequest( ).logout( );
            
            // retrieve user entity
            UserEntity currentUser = new UserFacade( ).getUser( username , password );
            
            System.out.println("Retrieved the user (email) : " + currentUser.getEmail() );

            // add the user to the session map
            setCurrentUser( currentUser );

            // Validate the provided user name and password in the password
            // validation realm used by the web container login mechanism
            // configured for the ServletContext.
            getHttpRequest( ).login( username , currentUser.getUserPassword() );

            outcome = "pretty:" + userType + "Home";
        }
        catch( ServletException ex ){
            addErrorMessage( "loginForm" , "You've used an incorrect username or password." );
            ex.printStackTrace();
            System.out.println(ex);
            logError( String.format( "Error login the user in, username : %s", username ), ex );
        }
        catch( Exception ex ) {
            addErrorMessage( "loginForm" , "Error, unable to complete login." );
            System.out.println(ex);
            logError( String.format( "Error login the user in, username : %s", username ), ex );
        }
        return outcome;

    }
    

    /**
     * Logs the user out of the web application
     * @return outcome, the home page
     */
    public String logout( ) {
        final String outcome = "pretty:home";
        try {
            getHttpRequest( ).logout( );
            setCurrentUser( null );
        }
        catch( ServletException ex ) {
            logError( String.format(
                    "Error loggin the user out, username : %s" ,
                    ( getCurrentUser( ) != null ? getCurrentUser( )
                            .getUsername( ) : "null" ) ) , ex );
        }
        return outcome;
    }
    
    
    
    
    // ###############################################################
    // GETTER AND SETTERS
    // ###############################################################

    public String getPassword() {
        return password;
    }

    public void setPassword(String password) {
        this.password = password;
    }

    public String getUsername() {
        return username;
    }

    public void setUsername(String username) {
        this.username = username;
    }

}
