/*
 * Copyright 2015 Djembe.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package md.djembe.beans;

import java.io.Serializable;
import java.util.List;

import javax.annotation.PostConstruct;
import javax.faces.bean.ManagedBean;
import javax.faces.bean.SessionScoped;
import javax.validation.constraints.NotNull;

import md.djembe.entities.WebContentEntity;
import md.djembe.enums.WebContentType;
import md.djembe.facades.WebContentFacade;


@ManagedBean(name = "webContentBean")
@SessionScoped
public class WebContentBean extends AbstractBean implements Serializable {
	
    
	private static final long serialVersionUID = 1L;

	@NotNull
	private String contentKey;
    
	private String contentValue;
	
	private WebContentType contentType;
	
	private String contentDescription;
	
	private WebContentEntity webContentEntity;
	
	private List<WebContentEntity> webContentList;
	
	
	
	@PostConstruct
	public void init( ){
		retrieveWebContent( );
	}

	//############################################
    // CRUD
    //############################################
	
	
    /**
     * Add a new entry to the database
     * @return
     */
    public String createWebContent( ) {
        new WebContentFacade( ).createNewWebContent( contentKey , contentValue, contentType, contentDescription );
        retrieveWebContent( );
        resetFields( );
        return "pretty:listWebContent";
    }
    
    /**
     * navigate to the view webContent
     * @return
     */
    public String displayWebContent( WebContentEntity webContentEntity ) {
        this.webContentEntity = webContentEntity ;
        return "pretty:viewWebContent";
    }
    
    /**
     * Select the entity for edit
     * @return
     */
    public String editWebContent( WebContentEntity webContentEntity ) {
    	System.out.println("setting entity for edit : " + webContentEntity);
        this.webContentEntity = webContentEntity ;
        return "pretty:editWebcontent";
    }
    
    /**
     * Save the changes made to the entity
     * @return
     */
    public String updateWebcontent( WebContentEntity webContentEntity ) {
    	System.out.println("updating web content : " + webContentEntity);
    	if( webContentEntity != null){
    		new WebContentFacade( ).edit( webContentEntity );
    		retrieveWebContent( );
    		return "pretty:listWebContent";
    	}
    	return null;
    }
    
    /**
     * Remove the entity from the database
     * @return
     */
    public String deleteWebContent( WebContentEntity webContentEntity  ) {
    	if( webContentEntity != null ){
    		new WebContentFacade( ).remove( webContentEntity );
    		retrieveWebContent( );
    		return "pretty:listWebContent";
    	}
    	return null;
    }
    
    
    /**
     * Navigate to the create new entity page
     * @return
     */
    public String addNewWebContent( ) {
        resetFields( );
        return "pretty:newWebContent";
    }
    
    /**
     * navigate to the view webContent
     * @return
     */
    public String previewWebContent( WebContentEntity webContentEntity  ) {
        this.webContentEntity = webContentEntity ;
        return "pretty:viewWebContent";
    }
    
    
    private void retrieveWebContent( ) {
        webContentList = new WebContentFacade( ).findAll( );
    }
	
	
    private void resetFields( ) {
        contentKey = null;
        contentValue = null;
    }
    
    public WebContentType[] getWebContentTypes( ) {
        return WebContentType.values( );
    }
	
	
	
	// ###############################################################
    // GETTER AND SETTERS
    // ###############################################################
	
    public String getContentKey( ) {
        return contentKey;
    }
    
    public void setContentKey( String contentKey ) {
        this.contentKey = contentKey;
    }
    
    public String getContentValue( ) {
        return contentValue;
    }
    
    public void setContentValue( String contentValue ) {
        this.contentValue = contentValue;
    }

    public WebContentType getContentType( ) {
        return contentType;
    }

    public void setContentType( WebContentType contentType ) {
        this.contentType = contentType;
    }

    public String getContentDescription( ) {
        return contentDescription;
    }

    public void setContentDescription( String contentDescription ) {
        this.contentDescription = contentDescription;
    }

    public WebContentEntity getWebContentEntity( ) {
    	System.out.println("retrieving web content : " + webContentEntity);
        return webContentEntity;
    }

    public List<WebContentEntity> getWebContentList( ) {
        return webContentList;
    }
	

}
