/*
 * Copyright 2015 Djembe.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package md.djembe.beans;

import java.io.Serializable;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.PostConstruct;
import javax.faces.bean.ManagedBean;
import javax.faces.bean.SessionScoped;

import md.djembe.entities.WebPageEntity;
import md.djembe.facades.WebPageFacade;

@ManagedBean(name = "pageBean")
@SessionScoped
public class WebPageBean extends AbstractBean implements Serializable {

	private static final long serialVersionUID = 1L;

	private String pageName;
	private WebPageEntity pageEntity;
	private Map<String, String> webPages = new HashMap<>();

	@PostConstruct
	public void init() {
		System.out.println("init web pages...");
		for (WebPageEntity webPage : getWebPageList()) {
			webPages.put(webPage.getPageName(), webPage.getPageContent());
		}
	}

	public String createNewPage() {
		new WebPageFacade().createNewPage(pageName);
		return "/admin/pages/list?faces-redirect=true";
	}

	public String editWebPage(WebPageEntity pageEntity) {
		this.pageEntity = pageEntity;
		return "/admin/pages/edit?faces-redirect=true";
	}

	public String updateWebPage(WebPageEntity pageEntity) {
		new WebPageFacade().edit(pageEntity);
		return "/admin/pages/list?faces-redirect=true";
	}

	public String deleteWebPage(WebPageEntity pageEntity) {
		new WebPageFacade().remove(pageEntity);
		return "/admin/pages/list?faces-redirect=true";
	}

	public String getPageName() {
		return pageName;
	}

	public void setPageName(String pageName) {
		this.pageName = pageName;
	}

	public WebPageEntity getPageEntity() {
		return pageEntity;
	}

	public void setPageEntity(WebPageEntity pageEntity) {
		this.pageEntity = pageEntity;
	}

	public List<WebPageEntity> getWebPageList() {
		return new WebPageFacade().findAll();
	}

}
