/*
 * Copyright 2015 Djembe.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package md.djembe.crypto;

import org.mindrot.jbcrypt.BCrypt;


/**
 * Concrete implementation of password hashing using the Bcrypt scheme
 * 
 * @author M. Diallo
 *
 */
public class BCryptEncryptor implements Encryptor{
    
    protected BCryptEncryptor() {
    }    

    /* (non-Javadoc)
     * @see md.djembe.webapp.crypto.Encryptor#hashPassword(java.lang.String)
     */
    @Override
    public String hashPassword(String plainPassword) {       
       return BCrypt.hashpw(plainPassword, BCrypt.gensalt());
    }

    /* (non-Javadoc)
     * @see md.djembe.webapp.crypto.Encryptor#isMatchingPassword(java.lang.String, java.lang.String)
     */
    @Override
    public boolean isMatchingPassword(String plainPassword, String hashedPassword) {        
        return BCrypt.checkpw(plainPassword, hashedPassword);  
    }

}
