/*
 * Copyright 2015 Djembe.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package md.djembe.crypto;


/**
 * Class used to interact with the encryption of  and verification of plain text
 * 
 * @author M. Diallo
 *
 */
public class EncryptionManager {
    
     private Encryptor encryptor ;

       
    /**
     *  Hash the provided password 
     * @param plainPassword the password in plain text
     * @return  a hash password
     */
    public String hashPassword( String plainPassword ){
        return encryptor.hashPassword( plainPassword );
    }
    
    /** 
     * Verify a plain text, whether it matches a hashed value
     * @param plainPassword the password in plain text
     * @param hashedPassword the hashed password
     * @return true if the plain text would hash to the value
     */
    public boolean checkPassword(String plainPassword, String hashedPassword){
        return encryptor.isMatchingPassword(plainPassword, hashedPassword);
    }   

   
    public void setEncryptor(Encryptor encryptor) {
        this.encryptor = encryptor;
    }

}
