/*
 * Copyright 2015 Djembe.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package md.djembe.crypto;

/**
 * Encryption mechanisms to hash given String and 
 * check whether a string and a hashed value matches. 
 * 
 * @author M. Diallo
 *
 */
public interface Encryptor {	
	
	
    /**
     * Generates the hash value of a given String
     * @param plainPassword
     * @return a hashed password
     */
    public String hashPassword(String plainPassword);

    /**
     * Determines whether the plain String and the hashed value match
     * @param plainPassword
     * @param hashedPassword
     * @return true if the plain String would hash to the hash value.
     */
    public boolean isMatchingPassword(String plainPassword, String hashedPassword);

}
