/*
 * Copyright 2015 Djembe.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package md.djembe.entities;

import java.io.Serializable;

import javax.persistence.Basic;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.Table;


@Entity
@Table(name = "articles")
@NamedQueries({
    @NamedQuery(name = "ArticleEntity.findAll", query = "SELECT a FROM ArticleEntity a ORDER BY a.creationDate DESC"),
    @NamedQuery(name = "ArticleEntity.findByArticleId", query = "SELECT a FROM ArticleEntity a WHERE a.articleId = :articleId"),
    @NamedQuery(name = "ArticleEntity.findByArticleURL", query = "SELECT a FROM ArticleEntity a WHERE a.articleURL = :articleURL"),
    @NamedQuery(name = "ArticleEntity.findByArticleTitle", query = "SELECT a FROM ArticleEntity a WHERE a.articleTitle = :articleTitle"),
    @NamedQuery(name = "ArticleEntity.findByCreationDate", query = "SELECT a FROM ArticleEntity a WHERE a.creationDate = :creationDate")})
//@org.hibernate.annotations.Cache(usage = org.hibernate.annotations.CacheConcurrencyStrategy.READ_WRITE)
public class ArticleEntity implements Serializable {
    private static final long serialVersionUID = 1L;
    
    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @Basic(optional = false)
    @Column(name = "articleId")
    private Long articleId;
    
    @Column(name = "articleURL")
    private String articleURL;
    
    @Basic(optional = false)    
    @Column(name = "articleTitle")
    private String articleTitle;
    
    @Basic(optional = false)   
    @Column(name = "articleBody")
    private String articleBody;
    
    @Basic(optional = false)   
    @Column(name = "articleType")
    private String articleType;
    
    @Basic(optional = false)   
    @Column(name = "articleLanguage")
    private String articleLanguage;
    
    @Column(name = "isPublic", nullable = false, columnDefinition = "TINYINT(1)")
    private boolean isPublic;
    
    @Column(name = "deleted", nullable = false, columnDefinition = "TINYINT(1)")
    private boolean deleted;
    
    @Column(name = "creationDate")
    private long creationDate;
    
    @JoinColumn(name = "userId", referencedColumnName = "userId")
    @ManyToOne(optional = true)
    private UserEntity userId;

    public ArticleEntity() {
    }

    public ArticleEntity( Long articleId ) {
        this.articleId = articleId;
    }

    public ArticleEntity(Long articleId, String articleURL, String articleTitle, String articleBody) {
        this.articleId = articleId;
        this.articleURL = articleURL;
        this.articleTitle = articleTitle;
        this.articleBody = articleBody;
    }

    public Long getArticleId() {
        return articleId;
    }

    public void setArticleId(Long articleId) {
        this.articleId = articleId;
    }

    public String getArticleURL() {
        return articleURL;
    }

    public void setArticleURL(String articleURL) {
        this.articleURL = articleURL;
    }

    public String getArticleTitle() {
        return articleTitle;
    }

    public void setArticleTitle(String articleTitle) {
        this.articleTitle = articleTitle;
    }

    public String getArticleBody() {
        return articleBody;
    }

    public void setArticleBody(String articleBody) {
        this.articleBody = articleBody;
    }

    public String getArticleType() {
        return articleType;
    }

    public void setArticleType(String articleType) {
        this.articleType = articleType;
    }

    public String getArticleLanguage() {
        return articleLanguage;
    }

    public void setArticleLanguage(String articleLanguage) {
        this.articleLanguage = articleLanguage;
    }

    public long getCreationDate() {
        return creationDate;
    }

    public void setCreationDate(long creationDate) {
        this.creationDate = creationDate;
    }

    public UserEntity getUserId() {
        return userId;
    }

    public void setUserId(UserEntity userId) {
        this.userId = userId;
    }

    public boolean isIsPublic() {
        return isPublic;
    }

    public void setIsPublic(boolean isPublic) {
        this.isPublic = isPublic;
    }

    public boolean isDeleted() {
        return deleted;
    }

    public void setDeleted(boolean deleted) {
        this.deleted = deleted;
    }
    
    

    @Override
    public int hashCode() {
        int hash = 0;
        hash += (articleId != null ? articleId.hashCode() : 0);
        return hash;
    }

    @Override
    public boolean equals(Object object) {
        // TODO: Warning - this method won't work in the case the id fields are not set
        if (!(object instanceof ArticleEntity)) {
            return false;
        }
        ArticleEntity other = (ArticleEntity) object;
        if ((this.articleId == null && other.articleId != null) || (this.articleId != null && !this.articleId.equals(other.articleId))) {
            return false;
        }
        return true;
    }

    @Override
    public String toString() {
        return "md.webapp.entities.ArticleEntity[ articleId=" + articleId + " ]";
    }

}