/*
 * Copyright 2015 Djembe.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package md.djembe.facades;

import java.util.List;

import javax.persistence.EntityManager;

/**
 *
 * @author Mamadou
 */
public abstract class AbstractFacade<T> {

    private Class<T> entityClass;

    public AbstractFacade(Class<T> entityClass) {
        this.entityClass = entityClass;
    }

    protected abstract EntityManager getEntityManager();

    /**
     * Create a new entry and persist it in the DB
     * @param entity
     */
    public void create(T entity) {
        // begin transaction
        EntityManager entityManager = getEntityManager( );
        
        entityManager.getTransaction( ).begin( );
        
        if( !entityManager.contains( entity ) ){
            // persist object - add to entity manager
            entityManager.persist( entity );
            // flush em - save to DB
            entityManager.flush( );
        }
        // commit transaction at all
        entityManager.getTransaction( ).commit( );
        // getEntityManager().persist(entity);
    }

    public void edit(T entity) {
    	EntityManager entityManager = getEntityManager( );
        entityManager.getTransaction( ).begin( );
        entityManager.merge( entity );
        entityManager.flush( );
        entityManager.getTransaction( ).commit( );
    }

    public void remove(T entity) {
    	EntityManager entityManager = getEntityManager( );
        entityManager.getTransaction( ).begin( );
    	entity = entityManager.merge(entity);
    	entityManager.remove( entity );
    	entityManager.flush( );
        entityManager.getTransaction( ).commit( );
    }

    public T find(Object id) {
        return getEntityManager().find(entityClass, id);
    }
    
    @SuppressWarnings( { "rawtypes" , "unchecked" } )
    public List<T> findAll() {
        javax.persistence.criteria.CriteriaQuery cq = getEntityManager().getCriteriaBuilder().createQuery();   
        cq.select(cq.from(entityClass));
        return getEntityManager().createQuery(cq).getResultList();
    }
    
    @SuppressWarnings( "unchecked" )
    public List<T> findAll(String namedQuery, String param) {        
        return getEntityManager().createNamedQuery(namedQuery).setParameter(1, param).getResultList();
    }

    @SuppressWarnings( { "rawtypes" , "unchecked" } )
    public List<T> findRange(int[] range) {
        javax.persistence.criteria.CriteriaQuery cq = getEntityManager().getCriteriaBuilder().createQuery();
        cq.select(cq.from(entityClass));
        javax.persistence.Query q = getEntityManager().createQuery(cq);
        q.setMaxResults(range[1] - range[0]);
        q.setFirstResult(range[0]);
        return q.getResultList();
    }
    
    @SuppressWarnings( { "rawtypes" , "unchecked" } )
    public int count() {
        javax.persistence.criteria.CriteriaQuery cq = getEntityManager().getCriteriaBuilder().createQuery();
        javax.persistence.criteria.Root<T> rt = cq.from(entityClass);
        cq.select(getEntityManager().getCriteriaBuilder().count(rt));
        javax.persistence.Query q = getEntityManager().createQuery(cq);
        return ((Long) q.getSingleResult()).intValue();
    }

  
}
