/*
 * Copyright 2015 Djembe.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package md.djembe.facades;

import java.util.ArrayList;
import java.util.List;

import javax.persistence.EntityManager;

import md.djembe.entities.ArticleEntity;
import md.djembe.entities.UserEntity;
import md.djembe.exceptions.ArticleRetrievalException;
import md.djembe.exceptions.PersistEntityException;
import md.djembe.persistence.PersistenceUtil;

public class ArticleFacade extends AbstractFacade<ArticleEntity> {

    public ArticleFacade() {
        super( ArticleEntity.class );
    }

    @Override
    protected EntityManager getEntityManager() { 
        return PersistenceUtil.getEntityManager();
    }

    /**
     * Create a new article 
     * @param body
     * @param title
     * @param type 
     * @param language
     * @param user
     */
    public void createNewArticle( final String body , final String title , final String type ,
                                    final String language , final UserEntity user ) {
        try {
            ArticleEntity articleEntity = new ArticleEntity( );
            articleEntity.setArticleBody( body );
            articleEntity.setArticleTitle( title );
            articleEntity.setArticleURL( title.replace( " " , "-" ) );
            articleEntity.setArticleType( type );
            articleEntity.setArticleLanguage( language );
            articleEntity.setUserId( user );
            articleEntity.setCreationDate( System.currentTimeMillis( ) );
            create( articleEntity );
        } catch ( Throwable throwable ) {
            throw new PersistEntityException( throwable ) ;
        }
    }

   

    /**
     * @return
     */
    @SuppressWarnings( "unchecked" )
    public List<ArticleEntity> getAllArticle( ){
        List<ArticleEntity> resultList = new ArrayList<ArticleEntity>( );
        try {
            resultList =  (List<ArticleEntity>) getEntityManager().createQuery(
                "SELECT a FROM ArticleEntity a ORDER BY a.creationDate DESC" )
                .getResultList( );
        } catch ( Throwable throwable ) {
            throw new ArticleRetrievalException( throwable ) ;
        }
        return resultList;
    }

    /**
     * Retrieve all the article with the @param article type.
     * @return list of articles entities.
     */
    @SuppressWarnings( "unchecked" )
    public List<ArticleEntity> getAllArticles( final String articleType ) {
        List<ArticleEntity> resultList = new ArrayList<ArticleEntity>( );
        try {
            resultList =  (List<ArticleEntity>) getEntityManager().createQuery(
                        "SELECT a FROM ArticleEntity a WHERE a.articleType = :articleType AND a.deleted = :deleted ORDER BY a.creationDate DESC" )
                .setParameter( "articleType" , articleType )
                .setParameter( "deleted" , false ).getResultList( );
        } catch ( Throwable throwable ) {
            throw new ArticleRetrievalException( throwable ) ;
        }
        return resultList;
    }

    /**
     * Retrieve all the article marked as blog type
     * @return
     */
    public List<ArticleEntity> getAllBlogArticle( ) {
        return  getAllArticles( "blog" );
    }

}
