/*
 * Copyright 2015 Djembe.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package md.djembe.facades;

import java.io.InputStream;
import java.util.Scanner;

import javax.persistence.EntityManager;
import javax.servlet.ServletContext;

import md.djembe.persistence.PersistenceUtil;

import org.apache.log4j.Logger;

public class InstallFacade {

	/** The Logger */
	private static final Logger LOGGER = Logger.getLogger(InstallFacade.class);
	
	/**
	 * Loads the data from install.sql into the database
	 */
	public void loadInitialData(ServletContext servletContext) {
		if (LOGGER.isDebugEnabled()) {
			LOGGER.debug("Loading initial application data into the Database");
		}

		InputStream resourceAsStream = servletContext
				.getResourceAsStream("/WEB-INF/install.sql");
		String[] installSql = convertStreamToString(resourceAsStream).split( "--##" );
		for (String script : installSql) {
			LOGGER.info(String.format("Sql query : \n%s", script));
			EntityManager entityManager = getEntityManager();
			entityManager.getTransaction().begin();
			entityManager.createNativeQuery(script).executeUpdate();
			entityManager.getTransaction().commit();
		}

	}
	
	/**
	 * @return
	 */
	private EntityManager getEntityManager() {
		return PersistenceUtil.getEntityManager();
	}
	
	

	private static Scanner scanner;

	/**
	 * Retrieve the response as String from the input stream
	 * 
	 * @param inputStream
	 *            the source input
	 * @return the HTTP response
	 */
	private static String convertStreamToString(final InputStream inputStream) {
		scanner = new Scanner(inputStream);
		scanner.useDelimiter("\\A");
		return scanner.hasNext() ? scanner.next() : "";
	}

}
