/*
 * Copyright 2015 Djembe.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package md.djembe.facades;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.persistence.EntityManager;
import javax.persistence.NoResultException;

import md.djembe.entities.SettingEntity;
import md.djembe.persistence.PersistenceUtil;

public class SettingFacade extends AbstractFacade<SettingEntity> {

	public SettingFacade() {
		super(SettingEntity.class);
	}

	@Override
	protected EntityManager getEntityManager() {
		return PersistenceUtil.getEntityManager();
	}

	public SettingEntity findByName(final String settingName) {
		EntityManager entityManager = getEntityManager();
		try{
			return (SettingEntity) entityManager
					.createQuery( "SELECT s FROM SettingEntity s WHERE s.settingName = :settingName")
					.setParameter("settingName", settingName).getSingleResult();
		}catch( NoResultException noResultException){
			return null;
		}
		
	}

	/**
	 * Load the cache from the options table data
	 * 
	 * @return
	 */
	public Map<String, String> initCache() {

		Map<String, String> entries = new HashMap<String, String>();

		List<SettingEntity> options = findAll();

		for (SettingEntity option : options) {
			entries.put(option.getSettingName( ), option.getSettingValue( ) );
		}

		return entries;
	}

}
