/*
 * Copyright 2015 Djembe.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package md.djembe.facades;

import javax.persistence.EntityManager;
import javax.persistence.NoResultException;
import javax.persistence.Query;

import org.apache.log4j.Logger;

import md.djembe.entities.TemplateEntity;
import md.djembe.persistence.PersistenceUtil;

public class TemplateFacade extends AbstractFacade<TemplateEntity> {
    
    private static final Logger LOGGER = Logger.getLogger( TemplateFacade.class );

	public TemplateFacade() {
		super(TemplateEntity.class);
	}

	@Override
	protected EntityManager getEntityManager() {
		return PersistenceUtil.getEntityManager();
	}

	/**
	 * Add a new template data to the database
	 * @param templateName
	 * @param headTagContent
	 * @param headerContent
	 * @param footerContent
	 * @param scriptContent
	 */
	public void createNewTemplate(String templateName, String headTagContent,
			String headerContent, String footerContent, String scriptContent) {
		System.out.println("creating new template...");
		
		TemplateEntity template = new TemplateEntity();
		template.setTemplateName(templateName);
		template.setHeadTagContent(headTagContent);
		template.setHeaderContent(headerContent);
		template.setFooterContent(footerContent);
		template.setScriptContent(scriptContent);
		template.setActive(false);
		create(template);
	}
	
    /**
     * Retrieve the template entity for the public facing pages.
     * @return the template set as active
     */
    public TemplateEntity getActiveTemplate( ){
        TemplateEntity activeTemplate = null;
        try {

            Query query = getEntityManager( ).createQuery(
                    "SELECT t FROM TemplateEntity t WHERE t.active = :active" );
            query.setParameter( "active" , true );
            activeTemplate = (TemplateEntity) query.getSingleResult( );
        }
        catch( NoResultException noResultException ){
            LOGGER.warn( "No public pages templates found." );
        }
        return activeTemplate;
    }

}
