/*
 * Copyright 2015 Djembe.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package md.djembe.facades;

import javax.persistence.EntityManager;

import md.djembe.entities.WebContentEntity;
import md.djembe.enums.WebContentType;
import md.djembe.exceptions.PersistEntityException;
import md.djembe.persistence.PersistenceUtil;

public class WebContentFacade extends AbstractFacade<WebContentEntity> {

	public WebContentFacade( ) {
		super(WebContentEntity.class);
	}

	@Override
	protected EntityManager getEntityManager( ) {
		return PersistenceUtil.getEntityManager( );
	}
	
	/**
	 * Store a new key/value web content data to the database.
	 * @param key  the web content key
	 * @param value the web content value
	 */
	public void createNewWebContent( final String key, final String value, final WebContentType type, final String description ) {
	    try {
            WebContentEntity webContent = new WebContentEntity( );
            webContent.setContentKey( key );
            webContent.setContentValue( value );
            webContent.setContentType( type );
            webContent.setContentDescription( description );
            create( webContent );
	    } catch ( Throwable throwable ) {
            throw new PersistEntityException( throwable ) ;
        }
	}
	
	/**
	 * Retrieve web content data from the DB given the key
	 * @param contentKey the value of the key
	 * @return web content value
	 */
    public WebContentEntity getWebContent( final String contentKey ) {
        WebContentEntity webContent = null;
        webContent = ( WebContentEntity ) getEntityManager( )
                                        .createNamedQuery( "WebContentEntity.findByKey" )
                                        .setParameter( "contentKey" , contentKey )
                                        .getSingleResult( );

        return webContent;
    }
    

}
