/*
 * Copyright 2015 Djembe.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package md.djembe.facades;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.persistence.EntityManager;
import javax.persistence.NoResultException;

import md.djembe.entities.SettingEntity;
import md.djembe.entities.WebPageEntity;
import md.djembe.persistence.PersistenceUtil;

public class WebPageFacade extends AbstractFacade<WebPageEntity> {

	public WebPageFacade() {
		super(WebPageEntity.class);
	}

	@Override
	protected EntityManager getEntityManager() {
		return PersistenceUtil.getEntityManager();
	}

	public void createNewPage(final String name) {
		WebPageEntity pageEntity = new WebPageEntity();
		pageEntity.setPageName(name);
		create(pageEntity);
	}

	public WebPageEntity findByPageName(final String pageName) {
		try {
			return (WebPageEntity) getEntityManager()
					.createNamedQuery("WebPageEntity.findByPageName")
					.setParameter("pageName", pageName).getSingleResult();
		} catch (NoResultException noResultException) {
			return null;
		}
	}
	
	
	/**
     * Load the cache from the webpages table data 
     * @return
     */
    public Map<String, String> initCache() {
        
        Map<String , String> entries = new HashMap<String , String>( );

        List<WebPageEntity> webapges = findAll( );

        for( WebPageEntity page : webapges ) {
            entries.put( page.getPageName( ) , page.getPageContent( ) );
        }

        return entries;
    } 

}
