/*
 * Copyright 2015 Djembe.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package md.djembe.filters;

import java.io.IOException;

import javax.servlet.Filter;
import javax.servlet.FilterChain;
import javax.servlet.FilterConfig;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import javax.servlet.annotation.WebFilter;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import md.djembe.resources.DynamicResourceHandler;

import org.apache.log4j.Logger;

/**
 * Forward the Base URL to the app home page
 */
@WebFilter("/*")
public class UrlRewriteFilter implements Filter {

	/** The Logger */
	private static final Logger LOGGER = Logger
			.getLogger(DynamicResourceHandler.class);

	@Override
	public void doFilter(ServletRequest request, ServletResponse response,
			FilterChain chain) throws IOException, ServletException {

		HttpServletRequest httpRequest = (HttpServletRequest) request;
		HttpServletResponse httpResponse = (HttpServletResponse) response;

		final String requestURI = httpRequest.getRequestURI();

		if (LOGGER.isDebugEnabled()) {
			LOGGER.debug(String.format("Filtering requestURI : %s", requestURI));
		}

		if ("/".equals(requestURI)) {
			if (LOGGER.isDebugEnabled()) {
				LOGGER.debug(String.format("forwarding to /home.jsf"));
			}
			request.getRequestDispatcher("/home.jsf").forward(httpRequest,
					httpResponse);
			return;
		} else if (requestURI.endsWith(".css")) {
			if (LOGGER.isDebugEnabled()) {
				LOGGER.debug(String.format("CSS resource : %s, continuing",
						requestURI));
			}
			return;
			// continue;
		} else if (requestURI.endsWith(".js")) {
			if (LOGGER.isDebugEnabled()) {
				LOGGER.debug(String.format("JS resource : %s, continuing",
						requestURI));
			}
			return;
			// continue;
		} else if ("favicon.ico".equals(requestURI)) {
			if (LOGGER.isDebugEnabled()) {
				LOGGER.debug(String.format("favicon redirect : %s", requestURI));
			}
			// request.getRequestDispatcher("/images/favicon").forward(httpRequest,
			// httpResponse);
			return;
		} else if (requestURI.startsWith("/admin/")) {

			final StringBuilder builder = new StringBuilder(requestURI).insert(1, '_');
			if (!requestURI.endsWith(".jsf")) {
				builder.append(".jsf");
			}
			final String adminURI = builder.toString();
			if (LOGGER.isDebugEnabled()) {
				LOGGER.debug(String.format("admin pages, forwarding to : %s", adminURI));
			}
			request.getRequestDispatcher(adminURI).forward( httpRequest, httpResponse);
			return;
		} else if (!requestURI.endsWith(".jsf")) {
			final String jsfResource = requestURI + ".jsf";

			if (LOGGER.isDebugEnabled()) {
				LOGGER.debug(String.format("public pages, forwarding to : %s",
						jsfResource));
			}
			request.getRequestDispatcher(jsfResource).forward(httpRequest,
					httpResponse);
			return;
		}

		if (LOGGER.isDebugEnabled()) {
			LOGGER.debug("outside if, continuing...");
		}
		chain.doFilter(httpRequest, httpResponse);

	}

	@Override
	public void destroy() {
		// TODO Auto-generated method stub

	}

	@Override
	public void init(FilterConfig filterConfig) throws ServletException {
		// TODO Auto-generated method stub

	}

}
