package md.djembe.jsf.components;

import java.io.IOException;
import java.util.Map;

import javax.faces.component.FacesComponent;
import javax.faces.component.UIInput;
import javax.faces.component.UINamingContainer;
import javax.faces.context.FacesContext;
import javax.faces.context.ResponseWriter;

@FacesComponent( value="HtmlHelloInput")
public class HtmlHelloInput extends UIInput {

	public HtmlHelloInput() {
		setRendererType(null); // the component renders itself
	}
	
	
	@Override
	public void encodeEnd(FacesContext context) throws IOException {
		String clientId = getClientId(context);
		char separatorChar = UINamingContainer.getSeparatorChar(context);
		encodeInputField(context, clientId + separatorChar + "inputField");
		encodeSubmitButton(context, clientId + separatorChar + "submit");
		encodeOutputField(context);
	}
	
	@Override
	public void decode(FacesContext context) {
		Map<String, String> requestParameterMap = context.getExternalContext().getRequestParameterMap();
		String clientId = getClientId(context);
		char separatorChar = UINamingContainer.getSeparatorChar(context);
		String submittedHelloMsg = requestParameterMap.get(clientId + separatorChar + "inputField") ;
		setSubmittedValue(submittedHelloMsg);
		
	}
	
	private void encodeInputField( FacesContext context, String clientId ) throws IOException {
		//renders a standard HTML input field
		ResponseWriter writer = context.getResponseWriter( );
		writer.startElement("input", this);
		writer.writeAttribute("type", "text", null);
		writer.writeAttribute("name", clientId, "clientId");
		Object value = getValue();
		if(value != null){
			writer.writeAttribute("value", value.toString(), "value");
		}
		writer.writeAttribute("size", "8", null);
		writer.endElement("input");
	}
	
	private void encodeSubmitButton(FacesContext context, String clientId ) throws IOException {
		//renders a submit button
		ResponseWriter writer = context.getResponseWriter( );
		writer.startElement("input", this);
		writer.writeAttribute("type", "submit", null);
		writer.writeAttribute("name", clientId, "clientId");
		writer.writeAttribute("value", "Click Me !", null);
		writer.endElement("input");
	}
	
	private void encodeOutputField(FacesContext context ) throws IOException {
		ResponseWriter writer = context.getResponseWriter( );
		String helloMsg = (String) getAttributes().get("value");
		writer.startElement("p", this);
		writer.writeText("You entered: " + helloMsg, null);
		writer.endElement("p");
	}
	
	
	

}
