/*
 * Copyright 2015 Djembe.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package md.djembe.resources;

import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.net.URL;
import java.net.URLConnection;
import java.net.URLStreamHandler;
import java.nio.charset.StandardCharsets;

public class DynamicProtocolHandler extends URLStreamHandler {

	private String content;

	public DynamicProtocolHandler(String content) {
		this.content = content;
	}

	@Override
	protected URLConnection openConnection(URL url) throws IOException {
		return new DynamicURLConnection(url, content);
	}

	private static final class DynamicURLConnection extends URLConnection {

		private String content;

		protected DynamicURLConnection(URL url, String content) {
			super(url);
			this.content = content;
		}

		@Override
		public InputStream getInputStream() throws IOException {

			// if(!connected) connect();

			if (content != null) {
				return new ByteArrayInputStream(
						content.getBytes(StandardCharsets.UTF_8));
			}
			return null;
		}

		@Override
		public void connect() throws IOException {
		}

	}

}
