/*
 * Copyright 2015 Djembe.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package md.djembe.servlets;

import java.io.File;
import java.io.IOException;
import java.nio.file.Files;

import javax.servlet.ServletException;
import javax.servlet.annotation.WebServlet;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import md.djembe.cache.ApplicationCache;
import md.djembe.enums.WebAppProperties;

import org.apache.log4j.Logger;

/**
 * Servlet to serve images requests.
 * 
 * @author M Diallo
 *
 */
@SuppressWarnings("serial")
@WebServlet("/images/*")
public class ImageServlet extends HttpServlet {

	private static final Logger LOGGER = Logger.getLogger(ImageServlet.class);

	@Override
	protected void doGet(HttpServletRequest request,
			HttpServletResponse response) throws ServletException, IOException {

	    final String FILES_DIR = ApplicationCache.getEntry(
                WebAppProperties.SETTINGS ,
                WebAppProperties.IMAGES_PATH );
        
        if( FILES_DIR == null ){
            LOGGER.error( String
                    .format( "Uploaded files folder does not exist. Please create one before uploading files." ) );
            return;
        }

		String filename = request.getPathInfo().substring(1);
		
		File file = new File(FILES_DIR, filename);
		
		response.setHeader("Content-Type", getServletContext( ).getMimeType(filename) );
		
		response.setHeader("Content-Length", String.valueOf(file.length()));
		
		response.setHeader("Content-Disposition", "inline; filename=\"" + filename + "\"");
		
		Files.copy(file.toPath(), response.getOutputStream());
	}

}
