/*
 * Copyright 2015 Djembe.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package md.djembe.servlets;

import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.nio.file.Files;

import javax.servlet.ServletException;
import javax.servlet.annotation.MultipartConfig;
import javax.servlet.annotation.WebServlet;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.Part;

import md.djembe.aws.AmazonS3WebClient;
import md.djembe.cache.ApplicationCache;
import md.djembe.enums.MediaTypes;
import md.djembe.enums.WebAppProperties;
import md.djembe.facades.MediaFacade;

import org.apache.log4j.Logger;

@SuppressWarnings("serial")
@WebServlet("/admin/images/imageUpload")
@MultipartConfig(fileSizeThreshold = 1024 * 1024 * 2, // 2MB
                 maxFileSize = 1024 * 1024 * 10, // 10MB
                 maxRequestSize = 1024 * 1024 * 50)// 50MB
public class ImageUploadServlet extends HttpServlet {

	private static final Logger LOGGER = Logger.getLogger(ImageUploadServlet.class);

	private static final String FILES_DIR = ApplicationCache.getEntry( WebAppProperties.SETTINGS , WebAppProperties.IMAGES_PATH );

	/**
	 * Handles file upload
	 */
	@Override
	protected void doPost(HttpServletRequest request,
								HttpServletResponse response) throws ServletException, IOException {
		
		try {

            if( FILES_DIR == null ){
                LOGGER.error( String.format("Uploaded files folder does not exist. Please create one before uploading files.") );
                //return ; //TODO: return to a specific page with error message
			}
		    
            if( LOGGER.isDebugEnabled( ) ){
                LOGGER.debug( String.format( "Uploading files to external folder %s." , FILES_DIR ) );
            }

			for (Part part : request.getParts()) {
		        
		        String fileName = extractFileName(part);
		        
		        if (!fileName.isEmpty()){

					/*File filesDir = new File( FILES_DIR );

					if (!filesDir.exists()) {
						filesDir.mkdir();
					}*/

					File imageFile = new File( FILES_DIR + File.separator + fileName );

					try (InputStream input = part.getInputStream()) {
						Files.copy(input, imageFile.toPath());
					}

					AmazonS3WebClient.uploadToBucket("images/" + fileName, imageFile);

					String givenName = request.getParameter("fileName");

					persistImageDetailstoDB(givenName, givenName, fileName);
				}
		        
		    }
		}catch(Exception e) {
		    LOGGER.error( String.format( "Error uploading file to server; Error caused by \n%s" , e ) );
		    e.printStackTrace( );
		}
		

		response.sendRedirect("/admin/images/list");

	}

    private void persistImageDetailstoDB(final String title,
										 final String caption, final String fileName) {
        new MediaFacade( ).createNewMedia( MediaTypes.IMAGES , title , caption , fileName );

    }

	private String extractFileName(Part part) {
		String contentDisposition = part.getHeader("content-disposition");
		String[] items = contentDisposition.split(";");
		for (String item : items) {
			if (item.trim().startsWith("filename")) {
				return item.substring(item.indexOf("=") + 2, item.length() - 1);
			}
		}
		return "";
	}

}
